@@ -8,7 +8,7 @@ use JSON qw( to_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.54'; # VERSION
+our $VERSION = '1.55'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -87,14 +87,15 @@ sub gather_file_travis_yml
                           q{#  - cpanm -n Foo::Bar},
                           q{},
                           q{perl:},
-                          (map { "  - \"5.$_\""} qw( 8 10 12 14 16 18 )),
+                          (map { "  - \"5.$_\""} qw( 8 10 12 14 16 18 20 )),
                           q{},
                           q{#env:},
                           q{#  - FOO=bar},
                           q{},
                           q{#before_script: /bin/true},
                           q{},
-                          q{script: HARNESS_IS_VERBOSE=1 prove -lv t xt},
+                          q{script:},
+                          q{  - dzil test},
                           q{},
                           q{#after_script: /bin/true},
                           q{},
@@ -295,7 +296,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.54
+version 1.55
 
 =head1 DESCRIPTION
 
